@@ -2,7 +2,7 @@
 #'
 #' @description Core area (Core area metric)
 #'
-#' @param landscape Raster* Layer, Stack, Brick or a list of rasterLayers.
+#' @param landscape Raster* Layer, Stack, Brick, SpatRaster (terra), stars, or a list of rasterLayers.
 #' @param directions The number of directions in which patches should be
 #' connected: 4 (rook's case) or 8 (queen's case).
 #' @param consider_boundary Logical if cells that only neighbour the landscape
@@ -53,90 +53,9 @@
 #' web site: http://www.umass.edu/landeco/research/fragstats/fragstats.html
 #'
 #' @export
-lsm_p_core <- function(landscape, directions, consider_boundary, edge_depth) UseMethod("lsm_p_core")
-
-#' @name lsm_p_core
-#' @export
-lsm_p_core.RasterLayer <- function(landscape, directions = 8,
+lsm_p_core <- function(landscape, directions = 8,
                                    consider_boundary = FALSE, edge_depth = 1) {
-
-    result <- lapply(X = raster::as.list(landscape),
-                     FUN = lsm_p_core_calc,
-                     directions = directions,
-                     consider_boundary = consider_boundary,
-                     edge_depth = edge_depth)
-
-    layer <- rep(seq_along(result),
-                 vapply(result, nrow, FUN.VALUE = integer(1)))
-
-    result <- do.call(rbind, result)
-
-    tibble::add_column(result, layer, .before = TRUE)
-}
-
-#' @name lsm_p_core
-#' @export
-lsm_p_core.RasterStack <- function(landscape, directions = 8,
-                                   consider_boundary = FALSE, edge_depth = 1) {
-
-    result <- lapply(X = raster::as.list(landscape),
-                     FUN = lsm_p_core_calc,
-                     directions = directions,
-                     consider_boundary = consider_boundary,
-                     edge_depth = edge_depth)
-
-    layer <- rep(seq_along(result),
-                 vapply(result, nrow, FUN.VALUE = integer(1)))
-
-    result <- do.call(rbind, result)
-
-    tibble::add_column(result, layer, .before = TRUE)
-}
-
-#' @name lsm_p_core
-#' @export
-lsm_p_core.RasterBrick <- function(landscape, directions = 8,
-                                   consider_boundary = FALSE, edge_depth = 1) {
-
-    result <- lapply(X = raster::as.list(landscape),
-                     FUN = lsm_p_core_calc,
-                     directions = directions,
-                     consider_boundary = consider_boundary,
-                     edge_depth = edge_depth)
-
-    layer <- rep(seq_along(result),
-                 vapply(result, nrow, FUN.VALUE = integer(1)))
-
-    result <- do.call(rbind, result)
-
-    tibble::add_column(result, layer, .before = TRUE)
-}
-
-#' @name lsm_p_core
-#' @export
-lsm_p_core.stars <- function(landscape, directions = 8,
-                             consider_boundary = FALSE, edge_depth = 1) {
-
-    landscape <- methods::as(landscape, "Raster")
-
-    result <- lapply(X = raster::as.list(landscape),
-                     FUN = lsm_p_core_calc,
-                     directions = directions,
-                     consider_boundary = consider_boundary,
-                     edge_depth = edge_depth)
-
-    layer <- rep(seq_along(result),
-                 vapply(result, nrow, FUN.VALUE = integer(1)))
-
-    result <- do.call(rbind, result)
-
-    tibble::add_column(result, layer, .before = TRUE)
-}
-
-#' @name lsm_p_core
-#' @export
-lsm_p_core.list <- function(landscape, directions = 8,
-                            consider_boundary = FALSE, edge_depth = 1) {
+    landscape <- landscape_as_list(landscape)
 
     result <- lapply(X = landscape,
                      FUN = lsm_p_core_calc,
